OC.L10N.register(
    "photos",
    {
    "Public link" : "Offentligt link",
    "Photos" : "Fotos",
    "On This Day" : "På denne dag",
    "Your memories under your control" : "Dine minder under din egen kontrol",
    "All media" : "Alle medier",
    "Videos" : "Videoer",
    "Albums" : "Album",
    "Collaborative albums" : "Samarbejdsalbummer",
    "People" : "Personer",
    "Folders" : "Mapper",
    "Favorites" : "Favoritter",
    "On this day" : "På denne dag",
    "Shared with you" : "Delt med dig",
    "Tags" : "Tags",
    "Places" : "Steder",
    "Map" : "Kort",
    "Photos settings" : "Indstillinger for fotos",
    "Mark selection as favorite" : "Marker valg som favorit",
    "Add selection to favorites" : "Tilføj valg til favoritter",
    "Remove selection from favorites" : "Fjern valg fra favoritter",
    "Name of the album" : "Albummets navn",
    "Location of the album" : "Placering af albummet",
    "Back" : "Tilbage",
    "Add collaborators" : "Tilføj samarbejdspartnere",
    "Save" : "Gem",
    "Create album" : "Opret album",
    "Add to Album" : "Føj til album",
    "Add selection to album {albumName}" : "Tilføj markering til album {albumName}",
    "Shared by" : "Delt af",
    "Create a new album." : "Opret et nyt album.",
    "Create new album" : "Opret nyt album",
    "New album" : "Nyt album",
    "_%n item_::_%n photos and videos_" : ["%n enheder","%n fotos og videoer"],
    "Failed to fetch collaborators list." : "Kunne ikke hente listen over samarbejdspartnere.",
    "Failed to update album." : "Kunne ikke opdatere albummet.",
    "Add people or groups who can edit your album" : "Tilføj personer eller grupper, der kan redigere dit album",
    "Search people or groups" : "Søg efter personer eller grupper",
    "No recommendations. Start typing." : "Ingen anbefalinger. Begynd at skrive.",
    "Group" : "Gruppe",
    "Remove {collaboratorLabel} from the collaborators list" : "Fjern {collaboratorLabel} fra listen over samarbejdspartnere",
    "Copy the public link" : "Kopier det offentlige link",
    "Public link copied!" : "Offentlig link kopieret!",
    "Copy public link" : "Kopier offentligt link",
    "Delete the public link" : "Slet det offentlige link",
    "Create public link share" : "Opret offentligt delingslink",
    "Share via public link" : "Del via offentlig forbindelse",
    "This collection does not exist" : "Denne samling findes ikke",
    "An error occurred" : "Der opstod en fejl",
    "No picture for this day" : "Intet billede til denne dag",
    "Picture taken on this day will show up here." : "Billede taget på denne dag vil dukke op her.",
    "More photos from this day" : "Flere fotos fra denne dag",
    "_%n unassigned photo_::_%n unassigned photos_" : [" %n ikke tildelt foto"," %n ikke tildelte fotos"],
    "Favorite" : "Favorit",
    "Favorite image, open the full size \"{name}\" image" : "Favoritbillede, åben fuld størrelse \"{name}\" billede",
    "Open the full size \"{name}\" image" : "Åbn billedet \"{name}\" i fuld størrelse",
    "Select image {imageName}" : "Vælg billede {imageName}",
    "Open the \"{name}\" folder" : "Åbn mappen \"{name}\"",
    "Back to {folder}" : "Tilbage til {folder}",
    "Go back" : "Gå tilbage",
    "Share this folder" : "Del denne mappe",
    "Dates" : "Datoer",
    "Jump to specific date in list" : "Hop til specifik dato i listen",
    "Jump to {date}" : "Hop til {date}",
    "Add to {destination}" : "Føj til {destination}",
    "The destination folder is owned by {owner}" : "Destinationsmappen ejes af {owner}",
    "There are no photos or videos yet!" : "Der er endnu ingen fotos eller videoer!",
    "_{years} year ago_::_{years} years ago_" : ["{years} år siden","{years} år siden"],
    "Enable squared photos view" : "Aktiver kvadratisk fotovisning",
    "Delete source directory" : "Slet kildemappe",
    "Pick folder" : "Vælg mappe",
    "Select a source folder for your media" : "Vælg en kildemappe til dine medier",
    "All folders" : "Alle mapper",
    "Add a Photos source for the timelines" : "Tilføj en fotokilde til tidslinjer",
    "Add folder" : "Tilføj mappe",
    "Select the default upload location for your media" : "Vælg standard uploadplacering til dine medier",
    "Home" : "Hjemme",
    "Choose default Photos upload and Albums location" : "Vælg standard fotoupload og albumplacering",
    "Choose a different folder" : "Vælg en anden mappe",
    "View" : "Vis",
    "Media folders" : "Mediemapper",
    "Choose the folders from where photos and videos are shown." : "Vælg de mapper, hvorfra billeder og videoer vises.",
    "Upload folder" : "Uploadmappe",
    "Choose the folder where photos and albums are uploaded to." : "Vælg mappen som fotos og albummer uploades til.",
    "_%n photo_::_%n photos_" : [" %n fotos"," %n fotos"],
    "Unselect all" : "Fravælg alle",
    "Add photos to this album" : "Tilføj fotos til dette album",
    "Manage collaborators for this album" : "Administrer samarbejdspartnere for dette album",
    "Open actions menu" : "Åbn handlingsmenu",
    "Edit album details" : "Rediger albumdetaljer",
    "Download all files in album" : "Download alle filer i album",
    "Delete album" : "Slet album",
    "Download selected files" : "Download markerede filer",
    "Remove selection from album" : "Fjern markering fra album",
    "This album does not have any photos or videos yet!" : "Dette album har endnu ingen fotos eller videoer!",
    "Add photos to {albumName}" : "Tilføj fotos til {albumName}",
    "Manage collaborators" : "Administrer samarbejdspartnere",
    "Save collaborators for this album." : "Gem samarbejdspartnere for dette album.",
    "Cover photo for album {albumName}" : "Forsidefoto til album {albumName}",
    "There is no album yet!" : "Der er endnu ikke noget album!",
    "This person could not be found" : "Denne person kunne ikke findes",
    "Rename person" : "Omdøb person",
    "Merge with different person" : "Sammenflet med anden person",
    "Download selected photos" : "Download markerede fotos",
    "Remove from favorites" : "Fjern fra favoritter",
    "Remove person" : "Fjern person",
    "Name of this person" : "Navn på denne person",
    "Save." : "Gem.",
    "Merge person" : "Sammenflet person",
    "Move to different person" : "Flyt til en anden person",
    "_Move photo to a different person_::_Move photos to a different person_" : ["Flyt foto til en anden person","Flyt fotos til en anden person"],
    "_Remove photo from person_::_Remove photos from person_" : ["Fjern foto fra person","Fjern fotos fra person"],
    "This might take some time depending on the size of your photo library." : "Dette kan tage noget tid afhængigt af størrelsen af dit fotobibliotek.",
    "Recognized people will show up here" : "Genkendte mennesker vil dukke op her",
    "This folder does not exist" : "Denne mappe findes ikke",
    "Loading folders …" : "Indlæser mapper..",
    "No photos in here" : "Ingen billeder her",
    "Taken on {date} at {time}" : "Taget den {date} kl {time}",
    "This place does not have any photos or videos yet!" : "Dette sted har ikke nogen fotos eller videoer endnu!",
    "Add photos to this place" : "Tilføj fotos til dette sted",
    "Cover photo for place {placeName}" : "Forsidefoto til sted {placeName}",
    "There is no place yet!" : "Der er endnu ikke noget sted!",
    "Cover photo for shared album {albumName}" : "Forsidebillede til delt album {albumName}",
    "Back to tags overview" : "Tilbage til tags oversigt",
    "No photos with this tag yet" : "Endnu ingen fotos med dette tag",
    "No tags yet" : "Ingen tags endnu",
    "Photos with tags will show up here" : "Billeder med tags vil blive vist her",
    "Popular tags" : "Populære tags",
    "All tags" : "Alle tags",
    "One of the source folders does not exist" : "En af kildemapperne eksisterer ikke",
    "Add to album" : "Tilføj til album",
    "Delete selection" : "Slet valgte",
    "No photos or videos in here" : "Ingen fotos eller videoer her",
    "Unassigned faces" : "Ikke tildelte ansigter",
    "_%n photos_::_%n photos_" : ["%n foto","%n billeder"],
    "Failed to fetch collection." : "Kunne ikke hente samlingen.",
    "Failed to fetch collections list." : "Kunne ikke hente samlingslisten.",
    "Failed to fetch faces list." : "Kunne ikke hente ansigtslisten.",
    "Error fetching files" : "Fejl ved hentning af filer",
    "All your media" : "Alle dine medier",
    "Album {title}" : "Album {title}",
    "Shared Albums" : "Delte albums",
    "Shared album {title}" : "Delt album {title}",
    "Public album {title}" : "Public album {title}",
    "Tagged photos" : "Taggede billeder",
    "Tagged photo {title}" : "Tagget foto {title}",
    "{title}'s face" : "{title}'s ansigt",
    "{startDate} to {endDate}" : "{startDate} til {endDate}",
    "Details" : "Detaljer",
    "Failed to rename {oldName} to {faceName}" : "Kunne ikke omdøbe {oldName} til {faceName}",
    "Failed to delete {faceName}" : "Kunne ikke slette {faceName}",
    "Failed to delete {fileId}" : "Kunne ikke slette {fileId}",
    "Failed to delete {fileName}" : "Kunne ikke slette {fileName}",
    "Failed to set favorite state for {fileId}" : "Kunne ikke indstille favorittilstand for {fileId}",
    "Failed to set favorite state for {fileName}" : "Kunne ikke indstille favorittilstand for {fileName}",
    "Could not load photos folder" : "Kunne ikke indlæse fotomappe",
    "One of the source folders does not exists" : "En af kildemapperne eksisterer ikke",
    "Add" : "Tilføj"
},
"nplurals=2; plural=(n != 1);");
